import logging

from rest_framework.generics import RetrieveAPIView

from core.permissions import IsStudent
from core.serializers import (FeedbackSerializer, StudentSerializer,
                              SubmissionSerializer)

log = logging.getLogger(__name__)


class StudentApiView(RetrieveAPIView):
    permission_classes = (IsStudent,)

    def get_object(self):
        log.debug("Serializing student of user '%s'", self.request.user.username)
        return self.request.user.student
    serializer_class = StudentSerializer


class SubmissionApiView(RetrieveAPIView):
    permission_classes = (IsStudent,)

    def get_queryset(self):
        return self.request.user.student.submissions
    serializer_class = SubmissionSerializer


class FeedbackApiView(RetrieveAPIView):
    permission_classes = (IsStudent,)

    def get_queryset(self):
        return [submission.feedback for submission in self.request.user.submissions]
    serializer_class = FeedbackSerializer
